@@ -35,7 +35,6 @@ def close_client(client: TonlibClient):
         return False
 
 
-
 def get_nft_owner(addr: str, client: TonlibClient = None):
     if not client:
         client = get_client(2)
@@ -52,7 +51,7 @@ async def _get_nft_owner(client: TonlibClient, addr: str):
     return owner_address
 
 
-def get_items(addresses: list, filename_with_nft_metadata=None, client: TonlibClient=None, max_requests: int = 1000, ls:int=0):
+def get_items(addresses: list, filename_with_nft_metadata = None, client: TonlibClient = None, max_requests: int = 1000, ls: int = 0):
     items = {}
     if filename_with_nft_metadata and 'json' not in filename_with_nft_metadata:
         raise Exception('Only .json files are expected')
@@ -67,25 +66,21 @@ def get_items(addresses: list, filename_with_nft_metadata=None, client: TonlibCl
             client = get_client(ls)
         tasks = []
         for addr in addresses[i * max_requests:min(len(addresses), max_requests * (i + 1))]:
-            tasks.append(get_item(client, addr, nft_items, items, ls))
+            tasks.append(get_item(client, addr, nft_items, items))
         # asyncio.set_event_loop(asyncio.SelectorEventLoop())
         try:
             asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks))
         except:
-            raise ton.tonlibjson.TonlibException
-        finally:
             close_client(client)
-
-        print('DONE')
+            raise ton.tonlibjson.TonlibException
+        else:
+            close_client(client)
     if len(nft_items) < len(addresses):
         raise Exception('SCANNED NOT ALL ITEMS')
     return {"nft_items": nft_items}
 
 
-async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict = None, ls=0):
-    if not client.tonlib_wrapper._is_working:
-        await client.tonlib_wrapper.close()
-        client = await _get_client(ls)
+async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict = None):
     account = await client.find_account(addr, preload_state=False)
     x = await account.get_nft_data()
     collection_address = x['collection_address'].to_string()
